-- $Id: psql-destroy.sql,v 1.3 2005/04/07 06:13:57 rurban Exp $

\set QUIET

--================================================================
-- Prefix for table names.
--
-- You should set this to the same value you specify for
-- DATABASE_PREFIX in config/config.ini

\set prefix 	''

\set qprefix '\'' :prefix '\''
\echo Dropping all PhpWiki tables with:
\echo '       prefix = ' :qprefix
\echo

\set page_tbl		:prefix 'page'
\set version_tbl	:prefix 'version'
\set recent_tbl		:prefix 'recent'
\set nonempty_tbl	:prefix 'nonempty'
\set link_tbl		:prefix 'link'
\set session_tbl	:prefix 'session'
\set pref_tbl		:prefix 'pref'
-- \set user_tbl	:prefix 'user'
\set member_tbl		:prefix 'member'
\set rating_tbl		:prefix 'rating'
\set accesslog_tbl	:prefix 'accesslog'

DROP TABLE :page_tbl CASCADE;
DROP TABLE :version_tbl CASCADE;
DROP TABLE :recent_tbl CASCADE;
DROP TABLE :nonempty_tbl CASCADE;
DROP TABLE :link_tbl CASCADE;
DROP TABLE :session_tbl;
DROP TABLE :pref_tbl CASCADE;
DROP TABLE :member_tbl CASCADE;
DROP TABLE :rating_tbl CASCADE;
DROP TABLE :accesslog_tbl CASCADE;
